==> okio-jvm-3.6.0-javadoc.jar: okio/okio/-file-not-found-exception/index.md <==
//[okio](../../../index.md)/[okio](../index.md)/[FileNotFoundException](index.md)

# FileNotFoundException

[common]\
expect class [FileNotFoundException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? = null) : [IOException](../-i-o-exception/index.md)

[nonJvm]\
actual open class [FileNotFoundException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?) : [IOException](../-i-o-exception/index.md)

[jvm]\
actual typealias [FileNotFoundException](index.md) = [java.io.FileNotFoundException](https://docs.oracle.com/javase/8/docs/api/java/io/FileNotFoundException.html)

## Constructors

| | |
|---|---|
| [FileNotFoundException](-file-not-found-exception.md) | [common]<br>expect constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? = null)<br>[nonJvm]<br>actual constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?) |

## Properties

| Name | Summary |
|---|---|
| cause | [common, nonJvm]<br>[common]<br>open val [cause](index.md#-654012527%2FProperties%2F1348982416): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?<br>[nonJvm]<br>open val [cause](index.md#-654012527%2FProperties%2F1730460553): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)? |
| message | [common, nonJvm]<br>[common]<br>open val [message](index.md#1824300659%2FProperties%2F1348982416): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?<br>[nonJvm]<br>open val [message](index.md#1824300659%2FProperties%2F1730460553): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? |

==> okio-jvm-3.9.1-javadoc.jar: okio/okio/-file-not-found-exception/index.md <==
//[okio](../../../index.md)/[okio](../index.md)/[FileNotFoundException](index.md)

# FileNotFoundException

[common]\
expect class [FileNotFoundException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?) : [IOException](../-i-o-exception/index.md)

[nonJvm]\
actual open class [FileNotFoundException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?) : [IOException](../-i-o-exception/index.md)

[jvm]\
actual typealias [FileNotFoundException](index.md) = [java.io.FileNotFoundException](https://docs.oracle.com/javase/8/docs/api/java/io/FileNotFoundException.html)

## Constructors

| | |
|---|---|
| [FileNotFoundException](-file-not-found-exception.md) | [common]<br>expect constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?)<br>[nonJvm]<br>actual constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?) |

## Properties

| Name | Summary |
|---|---|
| cause | [common, nonJvm]<br>[common]<br>open val [cause](index.md#-654012527%2FProperties%2F1348982416): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?<br>[nonJvm]<br>open val [cause](index.md#-654012527%2FProperties%2F1730460553): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)? |
| message | [common, nonJvm]<br>[common]<br>open val [message](index.md#1824300659%2FProperties%2F1348982416): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?<br>[nonJvm]<br>open val [message](index.md#1824300659%2FProperties%2F1730460553): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? |
